<?php

namespace FiloBlu\OrderFlowRectifier\Model;

class Processor extends \Magento\Framework\Model\AbstractModel
{

    protected $rectifierPoolFactory;

    public function __construct(
        \Magento\Framework\Model\Context $context,
        \Magento\Framework\Registry $registry,
        RectifierPoolFactory $rectifierPoolFactory,
        \Magento\Framework\Model\ResourceModel\AbstractResource $resource = null,
        \Magento\Framework\Data\Collection\AbstractDb $resourceCollection = null,
        array $data = [])
    {
        parent::__construct(
            $context, $registry, $resource, $resourceCollection, $data);

        $this->rectifierPoolFactory = $rectifierPoolFactory;
    }

    public function process() {
        $writer = new \Zend\Log\Writer\Stream(BP . '/var/log/filoblu_order_flow_rectifier.log');
        $logger = new \Zend\Log\Logger();
        $logger->addWriter($writer);
        $logger->info('START RECTIFY PROCESS');
        $rectifiers = $this->rectifierPoolFactory->create()->getList();
        foreach ($rectifiers as $rectifier) {
            $ordersToProcess = $rectifier->loadOrders();
            $logger->info('Running rectifier "' . $rectifier->getTitle() . '" on ' . count($ordersToProcess) . ' orders');
            foreach ($ordersToProcess as $order) {
                $logger->info('Processing order ' . $order->increment_id);
                $success = $rectifier->executeSingle($order);
                if ($success) {
                    $logger->info('Done');
                } else {
                    $logger->info('Not done');
                }
            }
        }
        $logger->info('END RECTIFY PROCESS');
    }

}